@@ -1,12 +1,12 @@
 
 #include <test.hpp>
 
-#include "test/t/enum/testcase.pb.h"
+#include "t/enum/enum_testcase.pb.h"
 
 TEST_CASE("write enum field and check with libprotobuf") {
 
     std::string buffer;
-    protozero::pbf_writer pw(buffer);
+    protozero::pbf_writer pw{buffer};
 
     TestEnum::Test msg;
 
@@ -35,7 +35,7 @@ TEST_CASE("write enum field and check with libprotobuf") {
     }
 
     SECTION("max") {
-        pw.add_enum(1, std::numeric_limits<int32_t>::max());
+        pw.add_enum(1, std::numeric_limits<int32_t>::max() - 1);
 
         msg.ParseFromString(buffer);
 
