@@ -11,12 +11,12 @@ TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
     TestRepeatedPackedFixed32::Test msg;
 
     SECTION("empty") {
-        uint32_t data[] = { 17UL };
+        const uint32_t data[] = { 17UL };
         pw.add_packed_fixed32(1, std::begin(data), std::begin(data) /* !!!! */);
     }
 
     SECTION("one") {
-        uint32_t data[] = { 17UL };
+        const uint32_t data[] = { 17UL };
         pw.add_packed_fixed32(1, std::begin(data), std::end(data));
 
         msg.ParseFromString(buffer);
@@ -26,7 +26,7 @@ TEST_CASE("write repeated packed fixed32 field and check with libprotobuf") {
     }
 
     SECTION("many") {
-        uint32_t data[] = { 17UL, 0UL, 1UL, std::numeric_limits<uint32_t>::max() };
+        const uint32_t data[] = { 17UL, 0UL, 1UL, std::numeric_limits<uint32_t>::max() };
         pw.add_packed_fixed32(1, std::begin(data), std::end(data));
 
         msg.ParseFromString(buffer);
@@ -47,9 +47,9 @@ TEST_CASE("write from different types of iterators and check with libprotobuf")
     TestRepeatedPackedFixed32::Test msg;
 
     SECTION("from uint16_t") {
-        uint16_t data[] = { 1, 4, 9, 16, 25 };
+        const uint16_t data[] = { 1, 4, 9, 16, 25 };
 
-        pw.add_packed_fixed32(1, std::begin(data), std::end(data));
+        pw.add_packed_fixed<uint32_t>(1, std::begin(data), std::end(data));
     }
 
     SECTION("from string") {
@@ -59,7 +59,7 @@ TEST_CASE("write from different types of iterators and check with libprotobuf")
         std::istream_iterator<uint32_t> eod;
         std::istream_iterator<uint32_t> it(sdata);
 
-        pw.add_packed_fixed32(1, it, eod);
+        pw.add_packed_fixed<uint32_t>(1, it, eod);
     }
 
     msg.ParseFromString(buffer);
