@@ -1,12 +1,12 @@
 
 #include <test.hpp>
 
-#include "test/t/string/testcase.pb.h"
+#include "t/string/string_testcase.pb.h"
 
 TEST_CASE("write string field and check with libprotobuf") {
 
     std::string buffer;
-    protozero::pbf_writer pw(buffer);
+    protozero::pbf_writer pw{buffer};
 
     TestString::Test msg;
 
@@ -15,7 +15,7 @@ TEST_CASE("write string field and check with libprotobuf") {
 
         msg.ParseFromString(buffer);
 
-        REQUIRE(msg.s() == "");
+        REQUIRE(msg.s().empty());
     }
 
     SECTION("one") {
